@@ -1,8 +1,15 @@
+import warnings
 from threading import RLock as _RLock
 
 from OpenSSL import SSL as _ssl
 
 
+warnings.warn(
+    "OpenSSL.tsafe is deprecated and will be removed",
+    DeprecationWarning, stacklevel=3
+)
+
+
 class Connection:
     def __init__(self, *args):
         self._ssl_conn = _ssl.Connection(*args)
